@@ -11,6 +11,7 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 		// System Time Configuration
 		$scope.currentdate = "";
 		$scope.disableApplyButton = true;
+		$scope.displayHostnameType = false;
 
 		$scope.timeZoneNameOptions = dataSourceService.timeZoneNameOptions();
 		$scope.offsetHoursDataSource = dataSourceService.offsetHoursDataSource();
@@ -57,30 +58,31 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 				if(temp.timesourceName.indexOf("Clock is synchronized")>-1)	{
 					$scope.timesource = "NTP";
 				}else{
-					$scope.timesource = "Local";
+					$scope.timesource = translate('system_time_local');
 				}
 			}else{
-				$scope.timesource = "Local";
+				$scope.timesource = translate('system_time_local');
 			}
 			var cultureName = "";			
-			if(navigator.language.indexOf("zh") != -1){
-				cultureName = kendo.culture("zh")
-			}
-			else if(navigator.language.indexOf("ko") != -1){
-				cultureName = kendo.culture("ko");
-			}
-			else if(navigator.language.indexOf("ja") != -1){
-				cultureName = kendo.culture("ja")
-			}	
-
-			angular.element("#date").kendoDatePicker({
-				value: todayDate, //setting current date as default date
-				format: "yyyy-MM-dd",
-				change: function() {
-					$timeout(function(){$scope.disableApplyButton = false;});
-				},
-				culture: cultureName
-			});
+			$timeout(function(){			
+				if(navigator.language.indexOf("zh") != -1 || angular.element("#languageSelector").val() == "zh"){
+					cultureName = kendo.culture("zh");
+				}
+				else if(navigator.language.indexOf("ko") != -1 || angular.element("#languageSelector").val() == "ko"){
+					cultureName = kendo.culture("ko");
+				}
+				else if(navigator.language.indexOf("ja") != -1 || angular.element("#languageSelector").val() == "ja"){
+					cultureName = kendo.culture("ja");
+				}	
+				angular.element("#date").kendoDatePicker({
+					value: todayDate, //setting current date as default date
+					format: "yyyy-MM-dd",
+					change: function() {
+						$timeout(function(){$scope.disableApplyButton = false;});
+					},
+					culture: cultureName
+				});
+			},1000);
 
 			angular.element("#time").kendoTimePicker({
 				value: "00:00:00", //setting default time
@@ -173,10 +175,20 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 				if(ntpStatusTemp.indexOf("Clock is unsynchronized") > -1)
 					ntpStatusTemp="Unsynchronized"
 				else ntpStatusTemp="Synchronized"
+					var sourceAdd;
+					if(sourceAdress.indexOf("GigabitEthernet")!=-1){
+						sourceAdd = sourceAdress.replace("GigabitEthernet","Gi");
+					}else if(sourceAdress.indexOf("FastEthernet")!=-1){
+						sourceAdd = sourceAdress.replace("FastEthernet","Fa");
+					}else if(sourceAdress.indexOf("TenGigabitEthernet")!=-1){
+						sourceAdd = sourceAdress.replace("TenGigabitEthernet","Te");
+					}else{
+						sourceAdd = sourceAdress;
+					}
 				ntpGridDataList.push({
 					"HostName": hostName,
 					"VRFName": "None",
-					"SourceAddress": sourceAdress,
+					"SourceAddress": sourceAdd, //sourceAdress.replace("GigabitEthernet","Gi"),
 					"Status": ntpStatusTemp});
 			}
 		}
@@ -205,11 +217,14 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 			"ntpVRFNameText": "Mgmt-vrf",
 			"ntpVRFNameValue": "Mgmt-vrf"
 		});
+		$scope.ntpVlan = null;
+		$scope.ntpInterfaceOptions = null;
 		$timeout(function () {
 			$scope.ntpVlanDataSource=new kendo.data.ObservableArray(vlanOptions);
 			$scope.ntpInterfaceDataSource=new kendo.data.ObservableArray(interfaceOptions);
 			$scope.ntpVRFNameDataSource=new kendo.data.ObservableArray(vrfOptions);
-		}, 0);
+		}, 1000);
+		$scope.stpStackModeType = null;
 		$scope.ntpHostNameRadio= translate('ntp_word');
 		$scope.hostNamePlaceHolder=translate("ntp_host_placeholder");
 		$scope.showVRF=true;
@@ -218,9 +233,11 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 			if($scope.ntpHostNameRadio==translate('ntp_word')){
 				$scope.showVRF=true;
 				$scope.hostNamePlaceHolder=translate("ntp_host_placeholder");
+				$scope.ntpHostName='';
 			}else{
 				$scope.showVRF=false;
-				$scope.hostNamePlaceHolder=translate("ntp_host_placeholderTxt");;
+				$scope.hostNamePlaceHolder=translate("ntp_host_placeholderTxt");
+				$scope.ntpHostName='';
 			}
 		});
 		$scope.ntpVRF= false;
@@ -282,8 +299,13 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 						// return flase
 					}else{
 						var regExp=/^[0-9]+$/;
+						if ( !isNaN(parseInt(input.val().charAt(0))) )
+							return false;
+						if(input.val()=="0.0.0.0" || /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/.test(input.val()))
+							return false;
 						if(regExp.test(input.val()) || trimVal(input.val()) == "")
 							return false;
+
 					}
 					return true;
 				}
@@ -300,8 +322,10 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 		$scope.ntpDelBtn=true;
 		$scope.disNtpApplyBtn=true;
 		var ntpConfigCLI="";
+		$scope.newData=[];
 		// Edit vlan Group
 		var showNtpEdit = function(){
+			$("#ntpForm  span.k-tooltip-validation").hide();
 			var selected = this.dataItem(this.select());
 			$scope.ntpHostName=selected.HostName;
 			$timeout(function(){$scope.ntpShowEditSection = true});
@@ -318,16 +342,29 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 					else $scope.ntpHostNameRadio = translate('ntp_word');
 				}
 			}
-			if(selected.SourceAddress.indexOf("Gi") > -1){
+			for(var j=0;j<$scope.newData.length;j++) {
+				if($scope.newData[j].HostName==selected.HostName)
+					{
+						if($scope.newData[j].hostType=="IP")
+							$scope.ntpHostNameRadio = translate('clients_ip');
+						else if($scope.newData[j].hostType=="IPV6")
+								$scope.ntpHostNameRadio = translate('portconfig_adv_ipv6label');
+					}
+			}
+			if(selected.SourceAddress.indexOf("Gi") > -1 || selected.SourceAddress.indexOf("Fa") > -1 || selected.SourceAddress.indexOf("Te") > -1){
 				$scope.ntpSource=translate('portconfig_general_interface');
-				$scope.ntpVlan=selected.SourceAddress;
+				//$scope.ntpVlan=selected.SourceAddress;
 			}
 			else if(selected.SourceAddress.indexOf("Vlan") > -1){
 				$scope.ntpSource=translate('menu_vlan');
-				$scope.ntpInterface=selected.SourceAddress;
+				//$scope.ntpInterface=selected.SourceAddress;
 			}else {
 				$scope.ntpSource=translate('ntp_none');
-			}
+			}			
+			$timeout(function(){
+				$scope.ntpInterfaceOptions = selected.SourceAddress;
+				$scope.ntpVlan=selected.SourceAddress;
+			},100)
 			$scope.ntpDirty=selected.dirty;
 			$scope.ntpDelBtn=false;
 		};
@@ -354,9 +391,11 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 				sourceAddress='None';
 				status='Unsynchronized';
 				if($scope.ntpHostNameRadio==translate('clients_ip')){
+					$scope.newData.push({HostName:hostName,hostType:"IP"});
 					ntpConfigCLI += "ntp server ip " + hostName+"\n";
 				}else{
 					ntpConfigCLI += "ntp server ipv6 " + hostName+"\n";
+					$scope.newData.push({HostName:hostName,hostType:"IPV6"});
 				}
 			}else if($scope.ntpHostNameRadio==translate('ntp_word') && $scope.ntpVRF){
 				hostName=$scope.ntpHostName;
@@ -375,9 +414,9 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 			}else if($scope.ntpHostNameRadio==translate('ntp_word') && $scope.ntpSource==translate('portconfig_general_interface')){
 				hostName=$scope.ntpHostName;
 				vrfName="None";
-				sourceAddress=$scope.ntpInterface;
+				sourceAddress=$scope.ntpInterfaceOptions;
 				status='Unsynchronized';
-				if($scope.ntpInterface)
+				if($scope.ntpInterfaceOptions)
 				ntpConfigCLI += "ntp server "+hostName+" source " + sourceAddress+"\n";
 				else ntpConfigCLI += "ntp server "+hostName+"\n";;
 			}
@@ -388,33 +427,41 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 				status='Unsynchronized';
 				if($scope.ntpVlan){
 					if($scope.ntpHostNameRadio==translate('clients_ip')){
+						$scope.newData.push({HostName:hostName,hostType:"IP"});
 						ntpConfigCLI += "ntp server ip "+hostName+" source " + sourceAddress+"\n";
 					}else{
 						ntpConfigCLI += "ntp server ipv6 "+hostName+" source " + sourceAddress+"\n";
+						$scope.newData.push({HostName:hostName,hostType:"IPV6"});
 					}
 				}else{
 					if($scope.ntpHostNameRadio==translate('clients_ip')){
 						ntpConfigCLI += "ntp server ip "+hostName+"\n";
+						$scope.newData.push({HostName:hostName,hostType:"IP"});
 					}else{
 						ntpConfigCLI += "ntp server ipv6 "+hostName+"\n";
+						$scope.newData.push({HostName:hostName,hostType:"IPV6"});
 					}
 				}
 			}else if($scope.ntpHostNameRadio!=translate('ntp_word') && $scope.ntpSource==translate('portconfig_general_interface')){
 				hostName=$scope.ntpHostName;
 				vrfName="None";
-				sourceAddress=$scope.ntpInterface;
+				sourceAddress=$scope.ntpInterfaceOptions;
 				status='Unsynchronized';
-				if($scope.ntpInterface){
+				if($scope.ntpInterfaceOptions){
 					if($scope.ntpHostNameRadio==translate('clients_ip')){
 						ntpConfigCLI += "ntp server ip "+hostName+" source " + sourceAddress+"\n";
+						$scope.newData.push({HostName:hostName,hostType:"IP"});
 					}else{
 						ntpConfigCLI += "ntp server ipv6 "+hostName+" source " + sourceAddress+"\n";
+						$scope.newData.push({HostName:hostName,hostType:"IPV6"});
 					}
 				}else{
 					if($scope.ntpHostNameRadio==translate('clients_ip')){
 						ntpConfigCLI += "ntp server ip "+hostName+"\n";
+						$scope.newData.push({HostName:hostName,hostType:"IP"});
 					}else{
 						ntpConfigCLI += "ntp server ipv6 "+hostName+"\n";
+						$scope.newData.push({HostName:hostName,hostType:"IPV6"});
 					}
 				}
 			}
@@ -457,6 +504,8 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 		// Cancel Vlan Group
 		$scope.cancelNtpData=function(){
 			$scope.ntpShowEditSection = false;
+			$scope.ntpVlan = null;
+			$scope.ntpInterfaceOptions = null;
 		};
 		// Delete vlan group
 		$scope.delNtpRow=function(){
@@ -500,6 +549,7 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 		};
 		
 		$scope.ntpApplyBtn=function(){
+			$("#ntpForm  span.k-tooltip-validation").hide();
 			var result = requestRoutingService.getConfigCmdOutput(ntpConfigCLI);
 			if(result==""){
 				notificationService.showNotification(translate('ntp_success_msg'),translate('com_config_success_title'),'success');
@@ -509,7 +559,6 @@ app.controller('SystemCtrl', ['$scope','$filter','$timeout','validationService',
 			$scope.disNtpApplyBtn=true;
 			ntpConfigCLI='';
 		}
-		
 
 		$scope.gridDataSource = new kendo.data.DataSource({
 			pageSize : 10,
