@@ -1,29 +1,217 @@
-app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','executeCliCmdService','notificationService','dialogService','requestRoutingService',
-	function($scope,$timeout, $filter, gridCrudService,executeCliCmdService,notificationService,dialogService,requestRoutingService) {
+app.controller('VlanCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gridCrudService','executeCliCmdService','notificationService','dialogService','requestRoutingService',
+	function($scope,$rootScope,$timeout, $filter, gridCrudService,executeCliCmdService,notificationService,dialogService,requestRoutingService) {
 		var translate = $filter("translate");
 		var trimVal=$filter('trimValue');
-		//Showing configured vlan list in the grid
-		var showVlanBrList = requestRoutingService.getShowCmdOutput("show vlan brief","showVlanBrief");
-		showVlanBrList=showVlanBrList.ShowVlanBrief.VlanBriefTable.entry;
-		for(var i=0;i<showVlanBrList.length;i++){
-			if(showVlanBrList[i].status.indexOf("act/unsup")>-1)
-			    showVlanBrList[i].status="unsupported"
-		}
-		$scope.vlanData = new kendo.data.ObservableArray(showVlanBrList)
-		$scope.vlanDataSource = new kendo.data.DataSource({
-			pageSize : 10,
-			data : $scope.vlanData
-		});
+		var MaxVlan = 65;
 
-		$scope.vlanApplySection  = true;
-		$scope.vlanDeleteSection = true;
+
+	/*************VLAN2 configuration controller code.***************/
+		//Showing configured vlan list in the grid
+		$scope.loadVlanDetails = function(){
+			$scope.vlanApplySection  = true;
+			$scope.vlanDeleteSection = true;
+
+			var showVlanBrList = requestRoutingService.getShowCmdOutput("show vlan brief","showVlanBrief");
+			showVlanBrList=showVlanBrList.ShowVlanBrief.VlanBriefTable.entry;
+			for(var i=0;i<showVlanBrList.length;i++){
+				if(showVlanBrList[i].status.indexOf("act/unsup")>-1)
+				    showVlanBrList[i].status="unsupported"
+			}
+			$scope.vlanData = new kendo.data.ObservableArray(showVlanBrList)
+			$scope.vlanDataSource = new kendo.data.DataSource({
+				pageSize : 10,
+				data : $scope.vlanData
+			});
+	        $scope.layer2VlanGridOptions = {
+				dataSource: $scope.vlanDataSource,
+				editable : false,
+				sortable : true,
+				change : showVlanEdit ,
+				filterable : {
+					extra : false,
+					operators : {
+						string : {
+							eq : translate("com_is_equal"),
+							neq : translate("com_isnot_equal")
+						}
+					},
+					messages : {
+			            info: translate("com_page_dropDowntext"),
+			            filter: translate("com_btn_filter"),
+			            clear: translate("com_btn_clear")
+			        }
+				},
+				scrollable : false,
+				selectable : true,
+				pageable : {
+					messages: {
+						  display: translate("com_page_display"),
+						  empty: translate("com_page_empty"),
+						  page: translate("com_page_pagetext"),
+						  of:translate("com_page_of"),  
+						  itemsPerPage: translate("com_page_itemsPerPage"),
+						  first: translate("com_page_first"),
+						  previous: translate("com_page_previous"),
+						  next: translate("com_page_next"),
+						  last: translate("com_page_last"),
+						  refresh: translate("com_page_refresh"),
+						  morePages: translate("com_page_morePage")
+					},
+					previousNext : true,
+					info : true,
+					refresh : true,
+					pageSizes : gridCrudService.grid_page_sizes,
+					buttonCount : 5
+				},
+				columns : [{
+					field : "vlan",
+					title : translate("vlan_id"),
+					width : "10%"
+				}, {
+					field : "name",
+					title : translate("com_name"),
+					width : "20%"
+				}, {
+					field : "status",
+					title : translate("com_status"),
+					width : "10%"
+					//template:'<span>#= status ==="act/unsup" ? "unsupported" : status #</span>'
+				}, {
+					field : "ports",
+					title : translate("com_ports"),
+					width : "60%"
+				}]
+			};
+			if(showVlanBrList.length >= MaxVlan){
+				$scope.vlanAddSection = false;
+			}else{
+				$scope.vlanAddSection = true;
+			}
+        }
+			
 		var vlanEditData={
 			vlan: "",
 			name: "",
 			status: translate("com_active")
 		};
 
-		var vlanValidations = $("#vlanForm").kendoValidator({
+		
+		//Edit vlan grid value
+		$scope.vlanEditData = angular.copy(vlanEditData);
+		$scope.vlanDirty="";
+		var vlanConfigCLI="";
+		var showVlanEdit = function(){
+			angular.element("#vlanForm  span.k-tooltip-validation").hide();
+			var selected = this.dataItem(this.select());	
+			if (selected.vlan == 1 || selected.vlan == 1002 || selected.vlan == 1003 || selected.vlan == 1004 || selected.vlan == 1005) {
+				$timeout(function(){$scope.vlanShowEditSection = false;$scope.vlanDeleteSection = true;$scope.vlanApplySection = true});
+			} else {
+				$timeout(function(){$scope.vlanShowEditSection = true;$scope.vlanDeleteSection = false;$scope.vlanIdState = true});
+			}			
+			$scope.vlanEditData.vlan = selected.vlan;
+			$scope.vlanEditData.name = selected.name;
+			if(selected.status=="active"){
+				$scope.vlanEditData.status = translate("com_active");
+			}else{
+				$scope.vlanEditData.status = translate("com_suspended");
+			}			
+			$scope.vlanDirty=selected.dirty;
+		};
+		
+		$scope.loadVlanDetails();
+
+		$scope.saveVlanData = function(){
+			if(vlanValidations.validate()){
+				$scope.vlanApplySection = false;
+				var status="";
+				if($scope.vlanDirty){  //add function	
+					if($scope.vlanEditData.status==translate("com_suspended")){
+						status="suspend";
+					}else{
+						status="active";
+					}
+					$scope.layer2VlanGrid.dataSource.add({"vlan": $scope.vlanEditData.vlan,"name": $scope.vlanEditData.name,"status": status});
+				}else{ //for edit
+					var selectedItem = $scope.layer2VlanGrid.dataItem($scope.layer2VlanGrid.select());
+					selectedItem.vlan = $scope.vlanEditData.vlan;
+					selectedItem.name = $scope.vlanEditData.name;
+					if($scope.vlanEditData.status==translate("com_suspended")){
+						status="suspend";
+					}else{
+						status="active";
+					}
+					selectedItem.status = status;
+				}
+
+				vlanConfigCLI += "vlan "+$scope.vlanEditData.vlan+"\n";
+				vlanConfigCLI += "name "+$scope.vlanEditData.name+"\n";
+				if($scope.vlanEditData.status==translate("com_suspended")){
+					vlanConfigCLI += "state suspend \n";
+				}else{
+					vlanConfigCLI += "state active \n";
+				}
+				$scope.vlanEditData.vlan = "";
+				$scope.vlanEditData.name = "";
+				$scope.vlanEditData.status = translate("com_active");
+				$scope.vlanShowEditSection = false;
+				
+				if($scope.layer2VlanGrid.dataSource._total >= MaxVlan){
+					$scope.vlanAddSection = false;
+				}else{
+					$scope.vlanAddSection = true;
+				}
+			}
+		}
+
+		$scope.deleteData = function(popup) {
+			var selectedItem = $scope.layer2VlanGrid.dataItem($scope.layer2VlanGrid.select());
+			$scope.layer2VlanGrid.dataSource.remove(selectedItem);
+			vlanConfigCLI += "no vlan ";
+			vlanConfigCLI += selectedItem.vlan;
+			vlanConfigCLI += "\n";
+			popup.close();		
+			$scope.vlanCancel();
+			if($scope.layer2VlanGrid.dataSource._total >= MaxVlan){
+				$scope.vlanAddSection = false;
+			}else{
+				$scope.vlanAddSection = true;
+			}	
+			$timeout(function(){$scope.vlanApplySection = false});
+		}
+
+		$scope.addVlanRow = function(){
+			$scope.vlanEditData = angular.copy(vlanEditData);
+			$scope.vlanShowEditSection = true;
+			$scope.vlanDirty=true;
+			$scope.vlanIdState = false;
+			$scope.vlanEditData.vlan = "";
+			$scope.vlanEditData.name = "";
+			$scope.vlanDeleteSection = true;
+			$scope.vlanEditData.status = translate("com_active");
+			angular.element("#vlanForm  span.k-tooltip-validation").hide();
+		};
+		$scope.vlanCancel = function() {
+			$timeout(function(){
+				angular.element("#vlanForm  span.k-tooltip-validation").hide();
+				$scope.vlanShowEditSection = false;
+				$scope.vlanDeleteSection = true;
+				$scope.vlanApplySection = true
+			});
+		};
+		$scope.applyVlan2Layer=function(){
+			var result = requestRoutingService.getConfigCmdOutput(vlanConfigCLI);
+			if(result==""){
+				notificationService.showNotification(translate('vlan_success_msg'),translate('com_config_success_title'),'success');
+			}else{
+				notificationService.showNotification(result.errorResponse,translate('com_config_fail_title'),'error');
+			}
+			vlanConfigCLI="";
+			$scope.vlanApplySection  = true;
+			$scope.loadVlanDetails();
+		}
+
+		// Layer2 VLAN Form validation
+		var vlanValidations = angular.element("#vlanForm").kendoValidator({
 			rules: {
 				duplicate:function(input){
 					var valMsg = input.data('duplicateMsg');
@@ -32,7 +220,7 @@ app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','e
 					}
 					if(!$scope.vlanDirty)
 						return true;
-					var vlanGrid = $("#layer2VlanGrid").data("kendoGrid");
+					var vlanGrid = angular.element("#layer2VlanGrid").data("kendoGrid");
 					var vlanGridData = vlanGrid.dataSource.data();
 					for(i=0;i<vlanGridData.length;i++){
 						vlanGridData[i];
@@ -88,163 +276,8 @@ app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','e
 			$scope.deleteData($scope.dlgVlan.data("kendoWindow"));
 		});
 
-
-		//Edit vlan grid value
-		$scope.vlanEditData = angular.copy(vlanEditData);
-		$scope.vlanDirty="";
-		var vlanConfigCLI="";
-		var showVlanEdit = function(){
-			$("#vlanForm  span.k-tooltip-validation").hide();
-			var selected = this.dataItem(this.select());			
-			if (selected.vlan == 1 || selected.vlan == 1002 || selected.vlan == 1003 || selected.vlan == 1004 || selected.vlan == 1005) {
-				$timeout(function(){$scope.vlanShowEditSection = false;$scope.vlanDeleteSection = true;$scope.vlanApplySection = true});
-			} else {
-				$timeout(function(){$scope.vlanShowEditSection = true;$scope.vlanDeleteSection = false;$scope.vlanIdState = true});
-			}			
-			$scope.vlanEditData.vlan = selected.vlan;
-			$scope.vlanEditData.name = selected.name;
-			if(selected.status=="active"){
-				$scope.vlanEditData.status = translate("com_active");
-			}else{
-				$scope.vlanEditData.status = translate("com_suspended");
-			}			
-			$scope.vlanDirty=selected.dirty;
-		};
-
-		$scope.saveVlanData = function(){
-			if(vlanValidations.validate()){
-				$scope.vlanApplySection = false;
-				var status="";
-				if($scope.vlanDirty){  //add function	
-					if($scope.vlanEditData.status==translate("com_suspended")){
-						status="suspend";
-					}else{
-						status="active";
-					}
-					$scope.layer2VlanGrid.dataSource.add({"vlan": $scope.vlanEditData.vlan,"name": $scope.vlanEditData.name,"status": status});
-				}else{ //for edit
-					var selectedItem = $scope.layer2VlanGrid.dataItem($scope.layer2VlanGrid.select());
-					selectedItem.vlan = $scope.vlanEditData.vlan;
-					selectedItem.name = $scope.vlanEditData.name;
-					if($scope.vlanEditData.status==translate("com_suspended")){
-						status="suspend";
-					}else{
-						status="active";
-					}
-					selectedItem.status = status;
-				}
-
-				vlanConfigCLI += "vlan "+$scope.vlanEditData.vlan+"\n";
-				vlanConfigCLI += "name "+$scope.vlanEditData.name+"\n";
-				if($scope.vlanEditData.status==translate("com_suspended")){
-					vlanConfigCLI += "state suspend \n";
-				}else{
-					vlanConfigCLI += "state active \n";
-				}
-				$scope.vlanEditData.vlan = "";
-				$scope.vlanEditData.name = "";
-				$scope.vlanEditData.status = translate("com_active");
-				$scope.vlanShowEditSection = false;
-			}
-		}
-
-		$scope.deleteData = function(popup) {
-			var selectedItem = $scope.layer2VlanGrid.dataItem($scope.layer2VlanGrid.select());
-			$scope.layer2VlanGrid.dataSource.remove(selectedItem);
-			vlanConfigCLI += "no vlan ";
-			vlanConfigCLI += selectedItem.vlan;
-			vlanConfigCLI += "\n";
-			popup.close();
-			$timeout(function(){$scope.vlanApplySection = false});
-		}
-
-		$scope.addVlanRow = function(){
-			$scope.vlanEditData = angular.copy(vlanEditData);
-			$scope.vlanShowEditSection = true;
-			$scope.vlanDirty=true;
-			$scope.vlanIdState = false;
-			$scope.vlanEditData.vlan = "";
-			$scope.vlanEditData.name = "";
-			$scope.vlanEditData.status = translate("com_active");
-			$("#vlanForm  span.k-tooltip-validation").hide();
-		};
-		$scope.vlanCancel = function() {
-			$timeout(function(){$scope.vlanShowEditSection = false;$scope.vlanDeleteSection = true;$scope.vlanApplySection = true});
-		};
-		$scope.applyVlan2Layer=function(){
-			var result = requestRoutingService.getConfigCmdOutput(vlanConfigCLI);
-			if(result==""){
-				notificationService.showNotification(translate('vlan_success_msg'),translate('com_config_success_title'),'success');
-			}else{
-				notificationService.showNotification(result.errorResponse,translate('com_config_fail_title'),'error');
-			}
-			vlanConfigCLI="";
-			$scope.vlanApplySection  = true;
-		}
-
-		$scope.layer2VlanGridOptions = {
-			dataSource: $scope.vlanDataSource,
-			editable : false,
-			sortable : true,
-			change : showVlanEdit ,
-			filterable : {
-				extra : false,
-				operators : {
-					string : {
-						eq : translate("com_is_equal"),
-						neq : translate("com_isnot_equal")
-					}
-				},
-				messages : {
-		            info: translate("com_page_dropDowntext"),
-		            filter: translate("com_btn_filter"),
-		            clear: translate("com_btn_clear")
-		        }
-			},
-			scrollable : false,
-			selectable : true,
-			pageable : {
-				messages: {
-					  display: translate("com_page_display"),
-					  empty: translate("com_page_empty"),
-					  page: translate("com_page_pagetext"),
-					  of:translate("com_page_of"),  
-					  itemsPerPage: translate("com_page_itemsPerPage"),
-					  first: translate("com_page_first"),
-					  previous: translate("com_page_previous"),
-					  next: translate("com_page_next"),
-					  last: translate("com_page_last"),
-					  refresh: translate("com_page_refresh"),
-					  morePages: translate("com_page_morePage")
-				},
-				previousNext : true,
-				info : true,
-				refresh : true,
-				pageSizes : gridCrudService.grid_page_sizes,
-				buttonCount : 5
-			},
-			columns : [{
-				field : "vlan",
-				title : translate("vlan_id"),
-				width : "10%"
-			}, {
-				field : "name",
-				title : translate("com_name"),
-				width : "20%"
-			}, {
-				field : "status",
-				title : translate("com_status"),
-				width : "10%"
-				//template:'<span>#= status ==="act/unsup" ? "unsupported" : status #</span>'
-			}, {
-				field : "ports",
-				title : translate("com_ports"),
-				width : "60%"
-			}]
-		};
-
 		//form validate
-		var vlanListValidations = $("#vlanListForm").kendoValidator({
+		var vlanListValidations = angular.element("#vlanListForm").kendoValidator({
 			rules: {
 				range: function (input) {
 					var count=0;
@@ -279,7 +312,7 @@ app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','e
 				duplicateRecord:function(input){
 					if(!$scope.vlanListDirty)
 						return true;
-					var ipDhGrid = $("#ipDhcpSnnopingGrid").data("kendoGrid");
+					var ipDhGrid = angular.element("#ipDhcpSnnopingGrid").data("kendoGrid");
 					var ipDhData = ipDhGrid.dataSource.data();
 					var newipDhData=[];
 					for(i=0;i<ipDhData.length;i++){
@@ -310,7 +343,7 @@ app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','e
 			}
 		}).data("kendoValidator");
 		//form validate
-		var vlanGroupFormValidate = $("#vlanGroupForm").kendoValidator({
+		var vlanGroupFormValidate = angular.element("#vlanGroupForm").kendoValidator({
 			rules: {
 				duplicate:function(input){
 					var valMsg = input.data('duplicateMsg');
@@ -375,13 +408,25 @@ app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','e
 		}).data("kendoValidator");
 
 		//controller code for vlan group page
-		var showVlanGrp = requestRoutingService.getShowCmdOutput("show vlan group","showVlanGroup");
-		if(showVlanGrp.ShowVlanGroup.entry){
-			showVlanGrp = showVlanGrp.ShowVlanGroup.entry;
-			if (typeof showVlanGrp == "object" && !showVlanGrp.length)
-				showVlanGrp = [showVlanGrp];
-		}else showVlanGrp=[];
-		$scope.vlanGrpData = new kendo.data.ObservableArray(showVlanGrp)
+		
+		$scope.showVlanGroups = true;	
+		$scope.vlanGrpData = [];	
+		if( ($rootScope.deviceInfo.type.indexOf("2960X")!=-1 && $rootScope.deviceInfo.type.indexOf("-LL")!=-1) || 
+			    ($rootScope.deviceInfo.type.indexOf("2960+")!=-1 && $rootScope.deviceInfo.type.indexOf("-S")!=-1) || 
+				($rootScope.deviceInfo.type.indexOf("2960C")!=-1 && $rootScope.deviceInfo.type.indexOf("-S")!=-1))
+		{		
+             $scope.showVlanGroups = false;
+		}else{
+			var showVlanGrp = requestRoutingService.getShowCmdOutput("show vlan group","showVlanGroup");
+			if(showVlanGrp.ShowVlanGroup.entry){
+				showVlanGrp = showVlanGrp.ShowVlanGroup.entry;
+				if (typeof showVlanGrp == "object" && !showVlanGrp.length)
+					showVlanGrp = [showVlanGrp];
+			}else {
+				showVlanGrp=[];
+			}
+			$scope.vlanGrpData = new kendo.data.ObservableArray(showVlanGrp)
+		}
 		var vlanGrpEditData={
 			VlanGroup: "",
 			VlanList: ""
@@ -402,7 +447,7 @@ app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','e
 		};
 		//Save vlan group
 		$scope.saveVlanGrpData = function() {
-			var vlGrpGrid = $("#vlanGroupGrid").data("kendoGrid");
+			var vlGrpGrid = angular.element("#vlanGroupGrid").data("kendoGrid");
 			var vlGrpData = vlGrpGrid.dataSource.data();
 			var VlanGroup = $scope.vlanGrpEditData.VlanGroup;
 
@@ -580,7 +625,7 @@ app.controller('VlanCtrl', ['$scope','$timeout', '$filter', 'gridCrudService','e
 		};
 		// vlan list save records
 		$scope.saveVlanListData = function(){
-			var ipDhGrid = $("#ipDhcpSnnopingGrid").data("kendoGrid");
+			var ipDhGrid = angular.element("#ipDhcpSnnopingGrid").data("kendoGrid");
 			var ipDhData = ipDhGrid.dataSource.data();
 			var vlanList = $scope.vlanListEditData.VlanList;
 			if(vlanListValidations.validate()){
